sparse_dense_matmul

Function sparse_dense_matmul 

pub fn sparse_dense_matmul<I: Index, T: ComplexField, LhsT: Conjugate<Canonical = T>, RhsT: Conjugate<Canonical = T>>(
    dst: MatMut<'_, T>,
    beta: Accum,
    lhs: SparseColMatRef<'_, I, LhsT>,
    rhs: MatRef<'_, RhsT>,
    alpha: T,
    par: Par,
)
multiplies a sparse matrix lhs by a dense matrix rhs, and stores or adds the result to dst. see faer::linalg::matmul::matmul for more details.

note

allows unsorted matrices.