sparse_sparse_matmul_numeric_scratch

Function sparse_sparse_matmul_numeric_scratch 

pub fn sparse_sparse_matmul_numeric_scratch<I: Index, T: ComplexField>(
    dst: SymbolicSparseColMatRef<'_, I>,
    par: Par,
) -> StackReq
computes the size and alignment of the workspace required to perform the numeric matrix multiplication into dst.