sparse_sparse_matmul_symbolic

Function sparse_sparse_matmul_symbolic 

pub fn sparse_sparse_matmul_symbolic<I: Index>(
    lhs: SymbolicSparseColMatRef<'_, I>,
    rhs: SymbolicSparseColMatRef<'_, I>,
) -> Result<(SymbolicSparseColMat<I>, SparseMatMulInfo), FaerError>
performs a symbolic matrix multiplication of a sparse matrix lhs by a sparse matrix rhs, and returns the result.

note

allows unsorted matrices, and produces a sorted output.